pylsqpack
=========

.. image:: https://img.shields.io/pypi/l/pylsqpack.svg
   :target: https://pypi.python.org/pypi/pylsqpack
   :alt: License

.. image:: https://img.shields.io/pypi/v/pylsqpack.svg
   :target: https://pypi.python.org/pypi/pylsqpack
   :alt: Version

.. image:: https://img.shields.io/pypi/pyversions/pylsqpack.svg
   :target: https://pypi.python.org/pypi/pylsqpack
   :alt: Python versions

.. image:: https://github.com/aiortc/pylsqpack/workflows/tests/badge.svg
   :target: https://github.com/aiortc/pylsqpack/actions
   :alt: Tests

.. image:: https://readthedocs.org/projects/pylsqpack/badge/?version=latest
   :target: https://pylsqpack.readthedocs.io/
   :alt: Documentation

``pylsqpack`` is a wrapper around the `ls-qpack`_ library. It provides Python
`Decoder` and `Encoder` objects to read or write HTTP/3 headers compressed
with QPACK.

To learn more about ``pylsqpack`` please `read the documentation`_.

.. _ls-qpack: https://github.com/litespeedtech/ls-qpack/
.. _read the documentation: https://pylsqpack.readthedocs.io/en/latest/
